==> api_compose-0.0.5.tar.gz: api_compose-0.0.5/src/api_compose/cli/utils/yaml_dumper.py <==
__all__ = ['get_yaml_with_representers']

from pathlib import Path, PosixPath
from typing import Union, List, Dict

from pydantic import BaseModel

from api_compose.core.logging import get_logger
from api_compose.root.models.scenario import ExecutionIdAssignmentEnum
from api_compose.services.assertion_service.models.jinja_assertion import AssertionStateEnum
from api_compose.services.common.field.text_field import TextFieldFormatEnum
from api_compose.services.composition_service.models.actions.states import ActionStateEnum
from api_compose.services.composition_service.models.executors.enum import ExecutorProcessorEnum
from api_compose.services.composition_service.models.protocols.protocols import ActionAPIProtocolEnum
from api_compose.services.composition_service.models.protocols.status_enums import OtherResponseStatusEnum, \
    HttpResponseStatusEnum
from api_compose.services.persistence_service.models.enum import BackendProcessorEnum
from api_compose.services.reporting_service.models.enum import ReportProcessorEnum

logger = get_logger(__name__)


def dump_model_as_yaml(
        model: BaseModel,
        file_path: Path
):
    dict_ = model.model_dump()

    output_folder = file_path.parent
    if not output_folder.exists():
        output_folder.mkdir(parents=True, exist_ok=True)

    with open(file_path, 'w') as f:
        get_yaml_with_representers().dump(dict_, f)


def get_yaml_with_representers():
    import yaml

    yaml.add_representer(Path, _str_path_representer)
    yaml.add_representer(PosixPath, _str_path_representer)
    yaml.add_representer(set, _str_list_representer)
    yaml.add_representer(BackendProcessorEnum, _str_enum_representer)
    yaml.add_representer(ReportProcessorEnum, _str_enum_representer)
    yaml.add_representer(TextFieldFormatEnum, _str_enum_representer)
    yaml.add_representer(ActionAPIProtocolEnum, _str_enum_representer)
    yaml.add_representer(OtherResponseStatusEnum, _int_enum_representer)
    yaml.add_representer(HttpResponseStatusEnum, _int_enum_representer)
    yaml.add_representer(ActionStateEnum, _str_enum_representer)
    yaml.add_representer(ExecutorProcessorEnum, _str_enum_representer)
    yaml.add_representer(ExecutionIdAssignmentEnum, _str_enum_representer)
    yaml.add_representer(AssertionStateEnum, _str_enum_representer)
    return yaml


def _str_list_representer(dumper, data):
    return dumper.represent_sequence('tag:yaml.org,2002:seq', list(data))


def _str_path_representer(dumper, data):
    return dumper.represent_scalar('tag:yaml.org,2002:str', str(data))


def _str_enum_representer(dumper, data):
    return dumper.represent_scalar('tag:yaml.org,2002:str', data.value)


def _int_enum_representer(dumper, data):
    return dumper.represent_int(data.value)

==> api_compose-0.0.8.tar.gz: api_compose-0.0.8/src/api_compose/cli/utils/yaml_dumper.py <==
__all__ = ['get_yaml_with_representers']

from pathlib import Path, PosixPath

from pydantic import BaseModel as _BaseModel

from api_compose.core.logging import get_logger
from api_compose.root.models.scenario import ExecutionIdAssignmentEnum
from api_compose.services.assertion_service.models.jinja_assertion import AssertionStateEnum
from api_compose.services.common.models.functional_testing import FunctionalTestingEnum
from api_compose.services.common.models.text_field.text_field import TextFieldFormatEnum
from api_compose.services.composition_service.models.actions.states import ActionStateEnum
from api_compose.services.composition_service.models.executors.enum import ExecutorProcessorEnum
from api_compose.services.composition_service.models.protocols.protocols import ActionAPIProtocolEnum
from api_compose.services.composition_service.models.protocols.status_enums import OtherResponseStatusEnum, \
    HttpResponseStatusEnum
from api_compose.services.persistence_service.models.enum import BackendProcessorEnum
from api_compose.services.reporting_service.models.enum import ReportProcessorEnum

logger = get_logger(__name__)


def dump_model_as_yaml(
        model: _BaseModel,
        file_path: Path
):
    dict_ = model.model_dump()

    output_folder = file_path.parent
    if not output_folder.exists():
        output_folder.mkdir(parents=True, exist_ok=True)

    with open(file_path, 'w') as f:
        get_yaml_with_representers().dump(dict_, f)
        logger.info(f"Model is saved at {file_path=}")



def get_yaml_with_representers():
    import yaml

    yaml.add_representer(Path, _str_path_representer)
    yaml.add_representer(PosixPath, _str_path_representer)
    yaml.add_representer(set, _str_list_representer)
    yaml.add_representer(BackendProcessorEnum, _str_enum_representer)
    yaml.add_representer(ReportProcessorEnum, _str_enum_representer)
    yaml.add_representer(TextFieldFormatEnum, _str_enum_representer)
    yaml.add_representer(ActionAPIProtocolEnum, _str_enum_representer)
    yaml.add_representer(OtherResponseStatusEnum, _int_enum_representer)
    yaml.add_representer(HttpResponseStatusEnum, _int_enum_representer)
    yaml.add_representer(ActionStateEnum, _str_enum_representer)
    yaml.add_representer(ExecutorProcessorEnum, _str_enum_representer)
    yaml.add_representer(ExecutionIdAssignmentEnum, _str_enum_representer)
    yaml.add_representer(AssertionStateEnum, _str_enum_representer)
    yaml.add_representer(FunctionalTestingEnum, _str_enum_representer)
    return yaml


def _str_list_representer(dumper, data):
    return dumper.represent_sequence('tag:yaml.org,2002:seq', list(data))


def _str_path_representer(dumper, data):
    return dumper.represent_scalar('tag:yaml.org,2002:str', str(data))


def _str_enum_representer(dumper, data):
    return dumper.represent_scalar('tag:yaml.org,2002:str', data.value)


def _int_enum_representer(dumper, data):
    return dumper.represent_int(data.value)
